@@ -546,7 +546,7 @@ class DataClient(object):
 
     @staticmethod
     def upload_user_face(school_id, file_path, student_id=None, teacher_id=None):
-        if not (student_id and teacher_id):
+        if not (student_id or teacher_id):
             return None
         data = {"student_id": student_id} if student_id else {"teacher_id": teacher_id}
         backbone = Backbone(school_id)
