@@ -80,15 +80,18 @@ class AvatarSync(BaseSync):
                 file_name = "{}-{}.jpg".format(name, number)
                 file_path = os.path.join(AVATAR_PATH, file_name)
                 self.write_file(avatar, file_path)
+                avatar_res, face_res = None, None
                 if number in student_number_map:
                     user_id = student_number_map[number]
-                    self.client.upload_user_avatar(self.school_id, file_path, user_id)
-                    self.client.upload_user_face(self.school_id, file_path, student_id=user_id)
+                    avatar_res = self.client.upload_user_avatar(self.school_id, file_path, user_id)
+                    face_res = self.client.upload_user_face(self.school_id, file_path, student_id=user_id)
                 if number in teacher_number_map:
                     user_id = teacher_number_map[number]
-                    self.client.upload_user_avatar(self.school_id, file_path, user_id)
-                    self.client.upload_user_face(self.school_id, file_path, teacher_id=user_id)
+                    avatar_res = self.client.upload_user_avatar(self.school_id, file_path, user_id)
+                    face_res = self.client.upload_user_face(self.school_id, file_path, teacher_id=user_id)
                 os.remove(file_path)
+                logger.info(avatar_res)
+                logger.info(face_res)
                 logger.info("already upload {}/{} avatar".format(row_index, total))
                 row_index += 1
 
